@@ -24,7 +24,7 @@
 #
 
 """
-Main code for gitwrapperlib
+Main code for gitwrapperlib.
 
 .. _Google Python Style Guide:
    http://google.github.io/styleguide/pyguide.html
@@ -40,12 +40,13 @@ except ImportError:
     # fallback: emulate the sh API with pbs
     import pbs
 
-    class Sh(object):  # pylint: disable=too-few-public-methods
+    class Sh:  # pylint: disable=too-few-public-methods
         """
-        Overloading pbs to look like sh
+        Overloading pbs to look like sh.
 
         https://stackoverflow.com/questions/28618906/porting-sh-1-11-based-code-to-windows
         """
+
         def __getattr__(self, attr):
             return pbs.Command(attr)
     sh = Sh()
@@ -53,7 +54,7 @@ from .gitwrapperlibexceptions import ExecutableNotFound
 
 __author__ = '''Costas Tyfoxylos <costas.tyf@gmail.com>'''
 __docformat__ = '''google'''
-__date__ = '''2018-01-02'''
+__date__ = '''02-01-2018'''
 __copyright__ = '''Copyright 2018, Costas Tyfoxylos'''
 __credits__ = ["Costas Tyfoxylos"]
 __license__ = '''MIT'''
@@ -68,11 +69,11 @@ LOGGER = logging.getLogger(LOGGER_BASENAME)
 LOGGER.addHandler(logging.NullHandler())
 
 
-class Git(object):
-    """Models the git command and contstructs some extra helper methods"""
+class Git:
+    """Models the git command and contstructs some extra helper methods."""
 
-    passthrough_methods = ('init', 'push', 'pull')
-    argument_methods = ('add', 'clone')
+    passthrough_methods = ('init', 'pull')
+    argument_methods = ('add', 'clone', 'push')
 
     def __init__(self):
         logger_name = u'{base}.{suffix}'.format(base=LOGGER_BASENAME,
@@ -96,40 +97,48 @@ class Git(object):
                 raise ExecutableNotFound
         return git
 
-    def __getattr__(self, name):
+    def __getattr__(self, name):  # pylint: disable=inconsistent-return-statements
         if name in self.passthrough_methods:
             return getattr(self._git, name)
-        elif name in self.argument_methods:
+        if name in self.argument_methods:
             def wrapper(*args, **kwargs):  # noqa
                 return getattr(self._git, name)(*args, **kwargs)
             return wrapper
 
     def remove(self, path):
-        """Removes a path with force"""
+        """Removes a path with force."""
         self._git.rm('-rf', path)
 
     def add_forced(self, path):
-        """Adds a path with force"""
+        """Adds a path with force."""
         self._git.add('-f', path)
 
     def commit(self, message, *args):
-        """Commits"""
+        """Commits."""
         self._git.commit('-m', message, *args)
 
     def add_remote_origin(self, url):
-        """Adds the remote origin"""
+        """Adds the remote origin."""
         self._git.remote('add', 'origin', url)
 
     def push_master(self):
-        """Pushes to master"""
+        """Pushes to master."""
         self._git.push('origin', 'master')
 
+    def push_force_master(self):
+        """Pushes to master."""
+        self._git.push('origin', 'master', '--force')
+
+    def push_force_branch(self, branch):
+        """Pushes to master."""
+        self._git.push('origin', branch, '--force')
+
     def branch_upstream_to_master(self):
-        """Branches upstream to master"""
+        """Branches upstream to master."""
         self._git.branch('-u', 'origin/master')
 
     def get_branches(self):
-        """Returns a list of the branches"""
+        """Returns a list of the branches."""
         return [self._sanitize(branch)
                 for branch in self._git.branch(color="never").splitlines()]
 
@@ -142,36 +151,36 @@ class Git(object):
         return value
 
     def get_current_branch(self):
-        """Returns the currently active branch"""
+        """Returns the currently active branch."""
         return next((self._sanitize(branch)
                      for branch in self._git.branch(color="never").splitlines()
                      if branch.startswith('*')),
                     None)
 
     def create_branch(self, name):
-        """Creates a branch"""
+        """Creates a branch."""
         self._git.branch(name)
 
     def remove_branch(self, name):
-        """Removes a branch"""
+        """Removes a branch."""
         self._git.branch('-d', name)
 
     def switch_branch(self, name):
-        """Switches to a branch"""
+        """Switches to a branch."""
         self._git.checkout(name)
 
     def list_tags(self):
-        """Lists existing tags"""
+        """Lists existing tags."""
         return self._git.tag()
 
     def add_tag(self, value):
-        """Tag with provided value"""
+        """Tag with provided value."""
         self._git.tag(value)
 
     def delete_tag(self, value):
-        """Delete the tag provided"""
+        """Delete the tag provided."""
         self._git.tag('-d', value)
 
     def create_patch(self, from_tag, to_tag):
-        """Create a patch between tags"""
-        return self._git.diff('{}..{}'.format(from_tag, to_tag))
+        """Create a patch between tags."""
+        return str(self._git.diff('{}..{}'.format(from_tag, to_tag), _tty_out=False))
